@@ -68,6 +68,11 @@ for it if it is not supplied as an argument.
 
 Hostname where mysql is located. DEFAULT: localhost
 
+=head3 --socket STRING
+
+Socket where the mysql.sock or mysqld.sock is located. 
+DEFAULT: mysql.sock 
+
 =head3 --port STRING
 
 The port your mysql is using. DEFAULT: 3306
@@ -178,8 +183,8 @@ use Data::Dumper;       # Helps with debugging
 use DBI;                # Database stuff
 use Getopt::Long;       # Parse command line options
 use File::Type;         # Know when a file is compressed
-use Graph::Directed;    # Model an utternace as a directed graph
-use List::MoreUtils;    # these should be built-in
+#use Graph::Directed;    # Model an utternace as a directed graph
+#use List::MoreUtils;    # these should be built-in
 
 
 use feature qw(say);
@@ -202,8 +207,9 @@ my $usage = $header."\n"
 ."--quiet       Print NOTHING to STDERR or STDOUT.\n"
 ."--help        Print this help screen.\n"
 ."DATABASE OPTIONS\n"
-."--database    Name of MySQL database to store CUI data. (Default=CUI_DB)\n"
+."--database    Name of MySQL database to store CUI data. (Default=CUI_Bigrams)\n"
 ."--hostname    Hostname for MySQL database. (Default=localhost)\n"
+."--socket      Socket where the mysql.sock or mysqld.sock is located.\n"
 ."--username    Username for MySQL access. (Optional, but will be prompted)\n"
 ."--password    Password for MySQL access. (Optional, but will be prompted)\n"
 ."MetaMap Machine Output File Options\n"
@@ -228,6 +234,7 @@ my $HELP = '';      # Prints usage and exits if true.
 
 my $database = "CUI_Bigrams";        # Values needed to connect to MySQL dbase.
 my $hostname = "localhost";
+my $socket = "/var/run/mysqld/mysqld.sock";
 my $port     = "3306";
 my $username;
 my $password;
@@ -244,6 +251,7 @@ GetOptions( 'debug'         => \$DEBUG,
             'plain'         => sub { $gzipped = 0 }, 
             'database=s'    => \$database,
             'hostname=s'    => \$hostname,
+	    'socket=s'      => \$socket,
             'port=s'        => \$port,
             'username=s'    => \$username,
             'password=s'    => \$password,
@@ -293,7 +301,7 @@ for my $file (@files) {
 {
 	
 say "Connecting to $database on $hostname" if $VERBOSE;
-my $dbh = open_mysql_database($database, $hostname, $port, $username, $password);
+my $dbh = open_mysql_database($database, $hostname, $port, $username, $password, $socket);
 
 my($filetime_s,$filetime_e,$dbtime_s,$dbtime_e,$total_time_s);
 
@@ -337,19 +345,22 @@ say "Finished." if $VERBOSE;
 #                           Database Subroutines
 ###############################################################################
 sub open_mysql_database {
-    my ($dbase, $host, $port, $user, $pass) = (@_);
+    my ($dbase, $host, $port, $user, $pass, $socket) = (@_);
     
     # See if database exists in the specified DBMS                        
     my @dbases = DBI->data_sources("mysql",
-      {"host" => $host, "user" => $user, password => $pass});
+      {"host" => $host, "user" => $user, 
+       password => $pass, "socket"=> $socket});
     my $dbase_exists = grep /DBI:mysql:$dbase/, @dbases;
-    
+
     # Connect to the database if it exists. Otherwise create it from scratch.
     my $dbh;                
     if ($dbase_exists) {
-        $dbh =  DBI->connect("DBI:mysql:database=$dbase;host=$host",
-                         $user, $pass,
-                         {'RaiseError' => 1});
+
+        $dbh =  DBI->connect("DBI:mysql:database=$dbase;host=$host;"
+			     ."mysql_socket=$socket",
+			     $user, $pass,
+			     {'RaiseError' => 1});
     } 
     else {
         $dbh = DBI->connect("DBI:mysql:host=$host", $user, $pass,
