@@ -203,7 +203,7 @@ if( defined $opt_help ) {
 #  if version is requested, show version
 if( defined $opt_version ) {
     $opt_version = 1;
-    #&showVersion();
+    &showVersion();
     exit;
 }
 
@@ -405,7 +405,8 @@ sub showHelp() {
     
     print "--help                   Prints this help message.\n\n";
 
-    print "--getdescendants         Calculates the association score taking into account the occurrences of descendants of the specified CUIs\n\n";
+    print "--getdescendants         Calculates the association score taking into account
+                         the occurrences of descendants of the specified CUIs\n\n";
 
     print "--config FILE            Configuration file\n\n";    
 
@@ -428,7 +429,8 @@ sub showHelp() {
     
     print "\n\nUMLS-Association Database Options: \n\n";
 
-    print "--assocdatabase STRING        Database containing CUI bigrams (DEFAULT: CUI_BIGRAMS)\n\n";
+    print "--assocdatabase STRING        Database containing CUI bigrams 
+                              (DEFAULT: CUI_BIGRAMS)\n\n";
     
     
 
